@@ -71,3 +71,15 @@ def append_new(thelist, value):
     if not value in thelist:
         thelist.append(value)
     return value
+
+def group(thelist):
+    """Count every element in thelist. e.g. ["a", "b", "c", "a", "b", "b"] => {"a": 2, "b": 3, "c": 1}.
+    """
+    info = {}
+    for x in thelist:
+        if x in info:
+            info[x] += 1
+        else:
+            info[x] = 1
+    return info
+
